@@ -126,7 +126,7 @@ class Database:
                        end_date_str
 
             response = requests.get(link_str)
-            print(response)
+
             #result = ast.literal_eval(json.loads(response.content))
             result = json.loads(json.loads(response.content).replace("'", "\""))
 
@@ -293,7 +293,7 @@ class Database:
         if False not in list(check_bool_dict.values()):
             link_url = 'http://www.hkfdb.net/data_api?'
             token_str = 'token=' + str(self.authToken)
-            database_str = 'database=' + 'hk_market_cap_hist'
+            database_str = 'database=' + 'hk_market_cap_hist_by_date'
             start_date_str = 'start_date=' + str(start_date)
             end_date_str = 'end_date=' + str(end_date)
             link_str = link_url + '&' + token_str + '&' + database_str + '&' + start_date_str + '&' + end_date_str
@@ -328,6 +328,47 @@ class Database:
                     err_msg += error + ','
             print(err_msg)
 
+    def get_hk_market_cap_hist_by_code(self, code):
+        
+        check_bool_dict = self.check_hk_code_args(code)
+
+        if False not in list(check_bool_dict.values()):
+            link_url = 'http://www.hkfdb.net/data_api?'
+            token_str = 'token=' + str(self.authToken)
+            database_str = 'database=' + 'hk_market_cap_hist_by_code'
+            code_str = 'code=' + str(code)
+            link_str = link_url + '&' + token_str + '&' + database_str + '&' + code_str
+            
+            response = requests.get(link_str)
+
+            json_content = json.loads(response.content)
+            json_content = json_content.replace(' nan', '\" nan\"')
+            result = json.loads(json_content.replace("'", "\""))
+
+            df_list = []
+            for item in result:
+                date_int = item['_id']
+                df = pd.DataFrame(item['content'])
+                if len(df) > 0:
+                    df['date'] = str(date_int)
+                    df_list.append(df)
+            df = pd.concat(df_list)
+
+            df = df.sort_values(by='date')
+            df = df.reset_index(drop=True)
+            df['date'] = pd.to_datetime(df['date'],format='%Y-%m-%d')
+            #df['record_date'] = pd.to_datetime(df['record_date'],format='%Y%m%d')
+            df = df[['date','code','issued_share_mil','market_cap_mil','cumulative_market_cap_mil']]
+            df = df.set_index('date')
+            return df
+
+        else:
+            err_msg = 'Error in: '
+            for error in check_bool_dict:
+                if check_bool_dict[error] == False:
+                    err_msg += error + ','
+            print(err_msg)
+
     def get_hk_buyback_by_code(self, code):
 
         link_url = 'http://www.hkfdb.net/data_api?'
@@ -1531,8 +1572,24 @@ class Database:
                            'exp_type': exp_type}
 
         return check_bool_dict
-    
-    
+
+    def check_hk_code_args(self, code):
+
+        try:
+            code_length = len(code) > 0
+        except:
+            code_length = False
+        try:
+            code_isdigit = code.isdigit()
+        except:
+            code_isdigit = False
+
+        check_bool_dict = {'code_length': code_length,
+                           'code_isdigit': code_isdigit}
+
+        return check_bool_dict
+
+
 ################################ other tools ################################ 
 
 def get_holiday_from_gov(year):
